==> phpwiki-1.2.2.tbz: www/data-dist/phpwiki/locale/nl/LC_MESSAGES/phpwiki.php <==
<?php

$locale["You entered an invalid login or password."] =
   "Je hebt een ongeldige gebruikersnaam of wachtwoord ingevoerd.";
$locale["You are about to remove '%s' permanently!"] =
   "Je staat op het punt '%s' voorgoed te verwijderen!";
$locale["Click %shere%s to remove the page now."] =
   "Klik %shier%s om de pagina nu te verwijderen.";
$locale["Otherwise press the \"Back\" button of your browser."] =
   "Druk anders op de \"Terug\" knop van je bladeraar.";
$locale["Function not yet implemented."] =
   "Functie nog niet gemplementeerd.";
$locale["Remove page"] =
   "Verwijder pagina";
$locale["Removed page '%s' succesfully."] =
   "Pagina '%s' verwijderd.";
$locale["templates/browse.html"] =
   "locale/nl/templates/browse.html";
$locale["templates/editpage.html"] =
   "locale/nl/templates/editpage.html";
$locale["templates/editlinks.html"] =
   "locale/nl/templates/editlinks.html";
$locale["templates/message.html"] =
   "locale/nl/templates/message.html";
$locale["./pgsrc"] =
   "locale/nl/pgsrc";
$locale["Current page:"] =
   "Huidige pagina:";
$locale["version %s"] =
   "versie %s";
$locale["last modified on %s"] =
   "laatste verandering op %s";
$locale["by %s"] =
   "door %s";
$locale["None"] =
   "Geen";
$locale["Archived page:"] =
   "Gearchiveerde pagina:";
$locale["Versions are identical"] =
   "Versies zijn identiek";
$locale["Diff of %s."] =
   "Diff van %s.";
$locale["FrontPage"] =
   "VoorPagina";
$locale["Describe %s here."] =
   "Beschrijf %s hier.";
$locale["Copy of %s"] =
   "Kopie van %s";
$locale["No page name passed into editpage!"] =
   "Geen paginanaam doorgegeven aan veranderpagina";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Deze pagina is afgesloten door de beheerder en kan niet veranderd worden.";
$locale["Sorry for the inconvenience."] =
   "Excuses voor het ongemak.";
$locale["Problem while editing %s"] =
   "Probleem tijdens veranderen %s";
$locale["Searching for \"%s\" ....."] =
   "Zoeken naar \"%s\" ...";
$locale["%d matches found in %d pages."] =
   "%d keer gevonden in %d pagina's.";
$locale["Full Text Search Results"] =
   "Volledige tekst zoek resultaten";
$locale["Cannot establish connection to database, giving up."] =
   "Kan verbinding naar data base niet tot stand brengen, geef op.";
$locale["Error message: %s"] =
   "Foutboodschap: %s";
$locale["Cannot open database %s, giving up."] =
   "Kan data base %s niet openen, geef op.";
$locale["Insert/update failed: %s"] =
   "Insert/update gefaald: %s";
$locale["Delete on %s failed: %s"] =
   "Delete op %s gefaald: %s";
$locale["Insert into %s failed: %s"] =
   "Insert in %s gefaald: %s";
$locale["MySQL error: %s"] =
   "MySQL fout: %s";
$locale["Error writing page '%s'"] =
   "Fout bij schrijven pagina `%s'";
$locale["Cannot delete '%s' from table '%s'"] =
   "Kan '%s' niet verwijderen uit tabel '%s'";
$locale["Enter a page name"] =
   "Geef de naam van een pagina";
$locale["Go"] =
   "Ga";
$locale["Show the page source and references"] =
   "Toon de bron tekst en de koppelingen van de pagina";
$locale["PageInfo"] =
   "PaginaInfo";
$locale["Page name '%s' is not in the database"] =
   "Pagina naam `%s' staat niet in de data base";
$locale["Current version"] =
   "Actuele versie:";
$locale["Archived version"] =
   "Gearchiveerde versie:";
$locale["RecentChanges"] =
   "RecenteVeranderingen";
$locale["PhpWiki is unable to save your changes, because another user edited and saved the page while you were editing the page too. If saving proceeded now changes from the previous author would be lost."] =
   "PhpWiki kan je veranderingen niet bewaren, want een andere gebruiker\nheeft de pagina veranderd terwijl jij de pagina ook aan het veranderen\nwas.  Als bewaren nu doorgang zou vinden, zouden de veranderingen van\nde vorige auteur verloren gaan.";
$locale["In order to recover from this situation follow these steps:"] =
   "Om uit deze benarde situatie te geraken, volg je deze stappen:";
$locale["Use your browser's <b>Back</b> button to go back to the edit page."] =
   "Gebruik de <b>Terug</b> knop van je bladeraar om terug te gaan naar de verander tekst pagina.";
$locale["Copy your changes to the clipboard or to another temporary place (e.g. text editor)."] =
   "Kopier je veranderingen naar het klipbord of een andere tijdelijke plaats (bijv. een tekst editor).";
$locale["<b>Reload</b> the page. You should now see the most current version of the page. Your changes are no longer there."] =
   "<b>Reload</b> de pagina.  Je zou nu de meest recente versie van de pagina moeten zien.  Jouw veranderingen staan er nu niet meer.";
$locale["Make changes to the file again. Paste your additions from the clipboard (or text editor)."] =
   "Breng je veranderingen aan de pagina opnieuw aan.  Plak je toevoeginen van het klipbord (of tekst editor).";
$locale["Press <b>Save</b> again."] =
   "Druk opnieuw op <b>Bewaar</b>.";
$locale["Problem while updating %s"] =
   "Probleem tijdens veranderen van %s";
$locale["Thank you for editing %s."] =
   "Bedankt voor het veranderen van %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "Je zorgvuldige aandacht voor detail wordt erg gewaardeerd.";
$locale["Title Search Results"] =
   "Volledige tekst zoek resultaten";
$locale["Inserting page %s, version %s from %s"] =
   "Voeg pagina %s toe, versie %s van %s";
$locale["WikiFatalError"] =
   "WikiFataleFout";
$locale["Search"] =
   "Zoek";
$locale["Nesting depth exceeded in SetHTMLOutputMode"] =
   "Stack grenzen overschreden in SetHTMLOutputMode";
$locale["%d best incoming links:"] =
   "%d beste inkomende koppelingen:";
$locale["%d best outgoing links:"] =
   "%d beste uitgaande koppelingen:";
$locale["%d most popular nearby:"] =
   "%d meest gevraagde in de buurt:";

;?>

==> phpwiki-1.2.10_1.tbz: www/data-dist/phpwiki/locale/nl/LC_MESSAGES/phpwiki.php <==
<?php

$locale["You entered an invalid login or password."] =
   "Je hebt een ongeldige gebruikersnaam of wachtwoord ingevoerd.";
$locale["You are about to remove '%s' permanently!"] =
   "Je staat op het punt '%s' voorgoed te verwijderen!";
$locale["Click %shere%s to remove the page now."] =
   "Klik %shier%s om de pagina nu te verwijderen.";
$locale["Otherwise press the \"Back\" button of your browser."] =
   "Druk anders op de \"Terug\" knop van je bladeraar.";
$locale["Function not yet implemented."] =
   "Functie nog niet gemplementeerd.";
$locale["Remove page"] =
   "Verwijder pagina";
$locale["Removed page '%s' succesfully."] =
   "Pagina '%s' verwijderd.";
$locale["templates/browse.html"] =
   "locale/nl/templates/browse.html";
$locale["templates/editpage.html"] =
   "locale/nl/templates/editpage.html";
$locale["templates/editlinks.html"] =
   "locale/nl/templates/editlinks.html";
$locale["templates/message.html"] =
   "locale/nl/templates/message.html";
$locale["./pgsrc"] =
   "locale/nl/pgsrc";
$locale["Current page:"] =
   "Huidige pagina:";
$locale["version %s"] =
   "versie %s";
$locale["last modified on %s"] =
   "laatste verandering op %s";
$locale["by %s"] =
   "door %s";
$locale["None"] =
   "Geen";
$locale["Archived page:"] =
   "Gearchiveerde pagina:";
$locale["Versions are identical"] =
   "Versies zijn identiek";
$locale["Diff of %s."] =
   "Diff van %s.";
$locale["FrontPage"] =
   "VoorPagina";
$locale["Describe %s here."] =
   "Beschrijf %s hier.";
$locale["Copy of %s"] =
   "Kopie van %s";
$locale["No page name passed into editpage!"] =
   "Geen paginanaam doorgegeven aan veranderpagina";
$locale["This page has been locked by the administrator and cannot be edited."] =
   "Deze pagina is afgesloten door de beheerder en kan niet veranderd worden.";
$locale["Sorry for the inconvenience."] =
   "Excuses voor het ongemak.";
$locale["Problem while editing %s"] =
   "Probleem tijdens veranderen %s";
$locale["Searching for \"%s\" ....."] =
   "Zoeken naar \"%s\" ...";
$locale["%d matches found in %d pages."] =
   "%d keer gevonden in %d pagina's.";
$locale["Full Text Search Results"] =
   "Volledige tekst zoek resultaten";
$locale["Cannot establish connection to database, giving up."] =
   "Kan verbinding naar data base niet tot stand brengen, geef op.";
$locale["Error message: %s"] =
   "Foutboodschap: %s";
$locale["Cannot open database %s, giving up."] =
   "Kan data base %s niet openen, geef op.";
$locale["Insert/update to table 'wiki' failed: %s"] =
   "Insert/update 'wiki' gefaald: %s";
$locale["Delete on %s failed: %s"] =
   "Delete op %s gefaald: %s";
$locale["Insert into %s failed: %s"] =
   "Insert in %s gefaald: %s";
$locale["Insert/update into table 'archive' failed: %s"] =
   "Insert/update 'archive' gefaald: %s";
$locale["MSSQL error: %s"] =
   "MSSQL fout: %s";
$locale["Insert/Update failed: %s"] =
   "Insert/update gefaald: %s";
$locale["Cannot delete '%s' from table '%s'"] =
   "Kan '%s' niet verwijderen uit tabel '%s'";
$locale["MySQL error: %s"] =
   "MySQL fout: %s";
$locale["Error writing page '%s'"] =
   "Fout bij schrijven pagina `%s'";
$locale["Enter a page name"] =
   "Geef de naam van een pagina";
$locale["Go"] =
   "Ga";
$locale["Show the page source and references"] =
   "Toon de bron tekst en de koppelingen van de pagina";
$locale["PageInfo"] =
   "PaginaInfo";
$locale["Page name '%s' is not in the database"] =
   "Pagina naam `%s' staat niet in de data base";
$locale["Current version"] =
   "Actuele versie:";
$locale["Archived version"] =
   "Gearchiveerde versie:";
$locale["RecentChanges"] =
   "RecenteVeranderingen";
$locale["PhpWiki is unable to save your changes, because another user edited and saved the page while you were editing the page too. If saving proceeded now changes from the previous author would be lost."] =
   "PhpWiki kan je veranderingen niet bewaren, want een andere gebruiker\nheeft de pagina veranderd terwijl jij de pagina ook aan het veranderen\nwas.  Als bewaren nu doorgang zou vinden, zouden de veranderingen van\nde vorige auteur verloren gaan.";
$locale["In order to recover from this situation follow these steps:"] =
   "Om uit deze benarde situatie te geraken, volg je deze stappen:";
$locale["Use your browser's <b>Back</b> button to go back to the edit page."] =
   "Gebruik de <b>Terug</b> knop van je bladeraar om terug te gaan naar de verander tekst pagina.";
$locale["Copy your changes to the clipboard or to another temporary place (e.g. text editor)."] =
   "Kopier je veranderingen naar het klipbord of een andere tijdelijke plaats (bijv. een tekst editor).";
$locale["<b>Reload</b> the page. You should now see the most current version of the page. Your changes are no longer there."] =
   "<b>Reload</b> de pagina.  Je zou nu de meest recente versie van de pagina moeten zien.  Jouw veranderingen staan er nu niet meer.";
$locale["Make changes to the file again. Paste your additions from the clipboard (or text editor)."] =
   "Breng je veranderingen aan de pagina opnieuw aan.  Plak je toevoeginen van het klipbord (of tekst editor).";
$locale["Press <b>Save</b> again."] =
   "Druk opnieuw op <b>Bewaar</b>.";
$locale["Problem while updating %s"] =
   "Probleem tijdens veranderen van %s";
$locale["Thank you for editing %s."] =
   "Bedankt voor het veranderen van %s.";
$locale["Your careful attention to detail is much appreciated."] =
   "Je zorgvuldige aandacht voor detail wordt erg gewaardeerd.";
$locale["Title Search Results"] =
   "Zoek resultaten";
$locale["Inserting page %s, version %s from %s"] =
   "Voeg pagina %s toe, versie %s van %s";
$locale["WikiFatalError"] =
   "WikiFataleFout";
$locale["Search"] =
   "Zoek";
$locale["%d best incoming links:"] =
   "%d beste inkomende koppelingen:";
$locale["%d best outgoing links:"] =
   "%d beste uitgaande koppelingen:";
$locale["%d most popular nearby:"] =
   "%d meest gevraagde in de buurt:";

;?>
